==> DateTime-Locale-1.35.tar.gz: DateTime-Locale-1.35/share/ks-Deva-IN.pl <==
{
  am_pm_abbreviated => [
    "AM",
    "PM",
  ],
  available_formats => {
    Bh => "h B",
    Bhm => "h:mm B",
    Bhms => "h:mm:ss B",
    E => "ccc",
    EBhm => "E h:mm B",
    EBhms => "E h:mm:ss B",
    EHm => "E HH:mm",
    EHms => "E HH:mm:ss",
    Ed => "d, E",
    Ehm => "E h:mm a",
    Ehms => "E h:mm:ss a",
    Gy => "G y",
    GyMMM => "G y MMM",
    GyMMMEd => "G y MMM d, E",
    GyMMMd => "G y MMM d",
    GyMd => "GGGGG y-MM-dd",
    H => "HH",
    Hm => "HH:mm",
    Hms => "HH:mm:ss",
    Hmsv => "HH:mm:ss v",
    Hmv => "HH:mm v",
    M => "L",
    MEd => "MM-dd, E",
    MMM => "LLL",
    MMMEd => "MMM d, E",
    "MMMMW-count-other" => "'week' W 'of' MMMM",
    MMMMd => "MMMM d",
    MMMd => "MMM d",
    Md => "MM-dd",
    d => "d",
    h => "h a",
    hm => "h:mm a",
    hms => "h:mm:ss a",
    hmsv => "h:mm:ss a v",
    hmv => "h:mm a v",
    ms => "mm:ss",
    y => "y",
    yM => "y-MM",
    yMEd => "y-MM-dd, E",
    yMMM => "y MMM",
    yMMMEd => "y MMM d, E",
    yMMMM => "y MMMM",
    yMMMd => "y MMM d",
    yMd => "y-MM-dd",
    yQQQ => "y QQQ",
    yQQQQ => "y QQQQ",
    "yw-count-other" => "'week' w 'of' Y",
  },
  code => "ks-Deva-IN",
  date_format_full => "EEEE, d MMMM y",
  date_format_long => "d MMMM y",
  date_format_medium => "d MMM y",
  date_format_short => "d/M/yy",
  datetime_format_full => "{0} \N{U+092a}\N{U+0947}\N{U+0920} {1}",
  datetime_format_long => "{0} \N{U+092a}\N{U+0947}\N{U+0920} {1}",
  datetime_format_medium => "{1}, {0}",
  datetime_format_short => "{1}, {0}",
  day_format_abbreviated => [
    "\N{U+091a}\N{U+0902}\N{U+0926}\N{U+093f}\N{U+0930}\N{U+0935}\N{U+093e}\N{U+0930}",
    "\N{U+092c}\N{U+0941}\N{U+0935}\N{U+093e}\N{U+0930}",
    "\N{U+092c}\N{U+094b}\N{U+0926}\N{U+0935}\N{U+093e}\N{U+0930}",
    "\N{U+092c}\N{U+094d}\N{U+0930}\N{U+0947}\N{U+0938}\N{U+0935}\N{U+093e}\N{U+0930}",
    "\N{U+091c}\N{U+0941}\N{U+092e}\N{U+094d}\N{U+092e}\N{U+093e}",
    "\N{U+092c}\N{U+091f}\N{U+0935}\N{U+093e}\N{U+0930}",
    "\N{U+0906}\N{U+0925}\N{U+0935}\N{U+093e}\N{U+0930}",
  ],
  day_format_narrow => [
    "\N{U+091a}",
    "\N{U+092c}",
    "\N{U+092c}",
    "\N{U+092c}",
    "\N{U+091c}",
    "\N{U+092c}",
    "\N{U+0905}",
  ],
  day_format_wide => [
    "\N{U+091a}\N{U+0902}\N{U+0926}\N{U+093f}\N{U+0930}\N{U+0935}\N{U+093e}\N{U+0930}",
    "\N{U+092c}\N{U+0941}\N{U+0935}\N{U+093e}\N{U+0930}",
    "\N{U+092c}\N{U+094b}\N{U+0926}\N{U+0935}\N{U+093e}\N{U+0930}",
    "\N{U+092c}\N{U+094d}\N{U+0930}\N{U+0947}\N{U+0938}\N{U+0935}\N{U+093e}\N{U+0930}",
    "\N{U+091c}\N{U+0941}\N{U+092e}\N{U+094d}\N{U+092e}\N{U+093e}",
    "\N{U+092c}\N{U+091f}\N{U+0935}\N{U+093e}\N{U+0930}",
    "\N{U+0906}\N{U+0925}\N{U+0935}\N{U+093e}\N{U+0930}",
  ],
  day_stand_alone_abbreviated => [
    "\N{U+091a}\N{U+0902}\N{U+0926}\N{U+093f}\N{U+0930}\N{U+0935}\N{U+093e}\N{U+0930}",
    "\N{U+092c}\N{U+0941}\N{U+0935}\N{U+093e}\N{U+0930}",
    "\N{U+092c}\N{U+094b}\N{U+0926}\N{U+0935}\N{U+093e}\N{U+0930}",
    "\N{U+092c}\N{U+094d}\N{U+0930}\N{U+0947}\N{U+0938}\N{U+0935}\N{U+093e}\N{U+0930}",
    "\N{U+091c}\N{U+0941}\N{U+092e}\N{U+094d}\N{U+092e}\N{U+093e}",
    "\N{U+092c}\N{U+091f}\N{U+0935}\N{U+093e}\N{U+0930}",
    "\N{U+0906}\N{U+0925}\N{U+0935}\N{U+093e}\N{U+0930}",
  ],
  day_stand_alone_narrow => [
    "\N{U+091a}",
    "\N{U+092c}",
    "\N{U+092c}",
    "\N{U+092c}",
    "\N{U+091c}",
    "\N{U+092c}",
    "\N{U+0905}",
  ],
  day_stand_alone_wide => [
    "\N{U+091a}\N{U+0902}\N{U+0926}\N{U+093f}\N{U+0930}\N{U+0935}\N{U+093e}\N{U+0930}",
    "\N{U+092c}\N{U+0941}\N{U+0935}\N{U+093e}\N{U+0930}",
    "\N{U+092c}\N{U+094b}\N{U+0926}\N{U+0935}\N{U+093e}\N{U+0930}",
    "\N{U+092c}\N{U+094d}\N{U+0930}\N{U+0947}\N{U+0938}\N{U+0935}\N{U+093e}\N{U+0930}",
    "\N{U+091c}\N{U+0941}\N{U+092e}\N{U+094d}\N{U+092e}\N{U+093e}",
    "\N{U+092c}\N{U+091f}\N{U+0935}\N{U+093e}\N{U+0930}",
    "\N{U+0906}\N{U+0925}\N{U+0935}\N{U+093e}\N{U+0930}",
  ],
  era_abbreviated => [
    "BC",
    "AD",
  ],
  era_narrow => [
    "BC",
    "AD",
  ],
  era_wide => [
    "BC",
    "AD",
  ],
  first_day_of_week => 7,
  glibc_date_1_format => "%A %d %b %Y %I:%M:%S %p %Z",
  glibc_date_format => "%-m/%-d/%y",
  glibc_datetime_format => "%A %d %b %Y %I:%M:%S %p",
  glibc_time_12_format => "%I:%M:%S %p %Z",
  glibc_time_format => "%I:%M:%S %p %Z",
  language => "Kashmiri",
  month_format_abbreviated => [
    "\N{U+091c}\N{U+0928}\N{U+0935}\N{U+0930}\N{U+0940}",
    "\N{U+092b}\N{U+093c}\N{U+0930}\N{U+0935}\N{U+0930}\N{U+0940}",
    "\N{U+092e}\N{U+093e}\N{U+0930}\N{U+094d}\N{U+091a}",
    "\N{U+0905}\N{U+092a}\N{U+094d}\N{U+0930}\N{U+0948}\N{U+0932}",
    "\N{U+092e}\N{U+0947}",
    "\N{U+091c}\N{U+0942}\N{U+0928}",
    "\N{U+091c}\N{U+0941}\N{U+0932}\N{U+093e}\N{U+0908}",
    "\N{U+0905}\N{U+0917}\N{U+0938}\N{U+094d}\N{U+0924}",
    "\N{U+0938}\N{U+0924}\N{U+0941}\N{U+0902}\N{U+092c}\N{U+0930}",
    "\N{U+0905}\N{U+0915}\N{U+0924}\N{U+0941}\N{U+092e}\N{U+094d}\N{U+092c}\N{U+0930}",
    "\N{U+0928}\N{U+0935}\N{U+0942}\N{U+092e}\N{U+092c}\N{U+0930}",
    "\N{U+0926}\N{U+0938}\N{U+0942}\N{U+092e}\N{U+092c}\N{U+0930}",
  ],
  month_format_narrow => [
    "\N{U+091c}",
    "\N{U+092b}\N{U+093c}",
    "\N{U+092e}",
    "\N{U+0905}",
    "\N{U+092e}",
    "\N{U+091c}",
    "\N{U+091c}",
    "\N{U+0905}",
    "\N{U+0938}",
    "\N{U+0913}",
    "\N{U+0928}",
    "\N{U+0926}",
  ],
  month_format_wide => [
    "\N{U+091c}\N{U+0928}\N{U+0935}\N{U+0930}\N{U+0940}",
    "\N{U+092b}\N{U+093c}\N{U+0930}\N{U+0935}\N{U+0930}\N{U+0940}",
    "\N{U+092e}\N{U+093e}\N{U+0930}\N{U+094d}\N{U+091a}",
    "\N{U+0905}\N{U+092a}\N{U+094d}\N{U+0930}\N{U+0948}\N{U+0932}",
    "\N{U+092e}\N{U+0947}",
    "\N{U+091c}\N{U+0942}\N{U+0928}",
    "\N{U+091c}\N{U+0941}\N{U+0932}\N{U+093e}\N{U+0908}",
    "\N{U+0905}\N{U+0917}\N{U+0938}\N{U+094d}\N{U+0924}",
    "\N{U+0938}\N{U+0924}\N{U+0941}\N{U+0902}\N{U+092c}\N{U+0930}",
    "\N{U+0905}\N{U+0915}\N{U+0924}\N{U+0941}\N{U+092e}\N{U+094d}\N{U+092c}\N{U+0930}",
    "\N{U+0928}\N{U+0935}\N{U+0942}\N{U+092e}\N{U+092c}\N{U+0930}",
    "\N{U+0926}\N{U+0938}\N{U+0942}\N{U+092e}\N{U+092c}\N{U+0930}",
  ],
  month_stand_alone_abbreviated => [
    "\N{U+091c}\N{U+0928}\N{U+0935}\N{U+0930}\N{U+0940}",
    "\N{U+092b}\N{U+093c}\N{U+0930}\N{U+0935}\N{U+0930}\N{U+0940}",
    "\N{U+092e}\N{U+093e}\N{U+0930}\N{U+094d}\N{U+091a}",
    "\N{U+0905}\N{U+092a}\N{U+094d}\N{U+0930}\N{U+0948}\N{U+0932}",
    "\N{U+092e}\N{U+0947}",
    "\N{U+091c}\N{U+0942}\N{U+0928}",
    "\N{U+091c}\N{U+0941}\N{U+0932}\N{U+093e}\N{U+0908}",
    "\N{U+0905}\N{U+0917}\N{U+0938}\N{U+094d}\N{U+0924}",
    "\N{U+0938}\N{U+0924}\N{U+0941}\N{U+0902}\N{U+092c}\N{U+0930}",
    "\N{U+0905}\N{U+0915}\N{U+0924}\N{U+0941}\N{U+092e}\N{U+094d}\N{U+092c}\N{U+0930}",
    "\N{U+0928}\N{U+0935}\N{U+0942}\N{U+092e}\N{U+092c}\N{U+0930}",
    "\N{U+0926}\N{U+0938}\N{U+0942}\N{U+092e}\N{U+092c}\N{U+0930}",
  ],
  month_stand_alone_narrow => [
    "\N{U+091c}",
    "\N{U+092b}\N{U+093c}",
    "\N{U+092e}",
    "\N{U+0905}",
    "\N{U+092e}",
    "\N{U+091c}",
    "\N{U+091c}",
    "\N{U+0905}",
    "\N{U+0938}",
    "\N{U+0913}",
    "\N{U+0928}",
    "\N{U+0926}",
  ],
  month_stand_alone_wide => [
    "\N{U+091c}\N{U+0928}\N{U+0935}\N{U+0930}\N{U+0940}",
    "\N{U+092b}\N{U+093c}\N{U+0930}\N{U+0935}\N{U+0930}\N{U+0940}",
    "\N{U+092e}\N{U+093e}\N{U+0930}\N{U+094d}\N{U+091a}",
    "\N{U+0905}\N{U+092a}\N{U+094d}\N{U+0930}\N{U+0948}\N{U+0932}",
    "\N{U+092e}\N{U+0947}",
    "\N{U+091c}\N{U+0942}\N{U+0928}",
    "\N{U+091c}\N{U+0941}\N{U+0932}\N{U+093e}\N{U+0908}",
    "\N{U+0905}\N{U+0917}\N{U+0938}\N{U+094d}\N{U+0924}",
    "\N{U+0938}\N{U+0924}\N{U+0941}\N{U+0902}\N{U+092c}\N{U+0930}",
    "\N{U+0905}\N{U+0915}\N{U+0924}\N{U+0941}\N{U+092e}\N{U+094d}\N{U+092c}\N{U+0930}",
    "\N{U+0928}\N{U+0935}\N{U+0942}\N{U+092e}\N{U+092c}\N{U+0930}",
    "\N{U+0926}\N{U+0938}\N{U+0942}\N{U+092e}\N{U+092c}\N{U+0930}",
  ],
  name => "Kashmiri India Devanagari",
  native_language => "\N{U+0915}\N{U+0949}\N{U+0936}\N{U+0941}\N{U+0930}",
  native_name => "\N{U+0915}\N{U+0949}\N{U+0936}\N{U+0941}\N{U+0930} \N{U+092d}\N{U+093e}\N{U+0930}\N{U+0924} \N{U+0926}\N{U+0947}\N{U+0935}\N{U+0928}\N{U+093e}\N{U+0917}\N{U+0930}\N{U+0940}",
  native_script => "\N{U+0926}\N{U+0947}\N{U+0935}\N{U+0928}\N{U+093e}\N{U+0917}\N{U+0930}\N{U+0940}",
  native_territory => "\N{U+092d}\N{U+093e}\N{U+0930}\N{U+0924}",
  native_variant => undef,
  quarter_format_abbreviated => [
    "Q1",
    "Q2",
    "Q3",
    "Q4",
  ],
  quarter_format_narrow => [
    1,
    2,
    3,
    4,
  ],
  quarter_format_wide => [
    "1st \N{U+0938}\N{U+0939} \N{U+092e}\N{U+093e}\N{U+0939}",
    "2nd \N{U+0938}\N{U+0939} \N{U+092e}\N{U+093e}\N{U+0939}",
    "3rd \N{U+0938}\N{U+0939} \N{U+092e}\N{U+093e}\N{U+0939}",
    "4th \N{U+0938}\N{U+0939} \N{U+092e}\N{U+093e}\N{U+0939}",
  ],
  quarter_stand_alone_abbreviated => [
    "Q1",
    "Q2",
    "Q3",
    "Q4",
  ],
  quarter_stand_alone_narrow => [
    1,
    2,
    3,
    4,
  ],
  quarter_stand_alone_wide => [
    "1st \N{U+0938}\N{U+0939} \N{U+092e}\N{U+093e}\N{U+0939}",
    "2nd \N{U+0938}\N{U+0939} \N{U+092e}\N{U+093e}\N{U+0939}",
    "3rd \N{U+0938}\N{U+0939} \N{U+092e}\N{U+093e}\N{U+0939}",
    "4th \N{U+0938}\N{U+0939} \N{U+092e}\N{U+093e}\N{U+0939}",
  ],
  script => "Devanagari",
  territory => "India",
  time_format_full => "a h:mm:ss zzzz",
  time_format_long => "a h:mm:ss z",
  time_format_medium => "a h:mm:ss",
  time_format_short => "a h:mm",
  variant => undef,
  version => 41,
}

==> DateTime-Locale-1.41.tar.gz: DateTime-Locale-1.41/share/ks-Deva-IN.pl <==
{
  am_pm_abbreviated => [
    "AM",
    "PM",
  ],
  available_formats => {
    Bh => "h B",
    Bhm => "h:mm B",
    Bhms => "h:mm:ss B",
    E => "ccc",
    EBhm => "E h:mm B",
    EBhms => "E h:mm:ss B",
    EHm => "E HH:mm",
    EHms => "E HH:mm:ss",
    Ed => "d, E",
    Ehm => "E h:mm a",
    Ehms => "E h:mm:ss a",
    Gy => "G y",
    GyMMM => "G y MMM",
    GyMMMEd => "G y MMM d, E",
    GyMMMd => "G y MMM d",
    GyMd => "GGGGG y-MM-dd",
    H => "HH",
    Hm => "HH:mm",
    Hms => "HH:mm:ss",
    Hmsv => "HH:mm:ss v",
    Hmv => "HH:mm v",
    M => "L",
    MEd => "MM-dd, E",
    MMM => "LLL",
    MMMEd => "MMM d, E",
    "MMMMW-count-other" => "'week' W 'of' MMMM",
    MMMMd => "MMMM d",
    MMMd => "MMM d",
    Md => "MM-dd",
    d => "d",
    h => "h a",
    hm => "h:mm\N{U+202f}a",
    hms => "h:mm:ss\N{U+202f}a",
    hmsv => "h:mm:ss\N{U+202f}a v",
    hmv => "h:mm a v",
    ms => "mm:ss",
    y => "y",
    yM => "y-MM",
    yMEd => "y-MM-dd, E",
    yMMM => "y MMM",
    yMMMEd => "y MMM d, E",
    yMMMM => "y MMMM",
    yMMMd => "MMM d, y",
    yMd => "M/d/y",
    yQQQ => "y QQQ",
    yQQQQ => "y QQQQ",
    "yw-count-other" => "'week' w 'of' Y",
  },
  code => "ks-Deva-IN",
  date_format_full => "EEEE, d MMMM y",
  date_format_long => "d MMMM y",
  date_format_medium => "d MMM y",
  date_format_short => "d/M/yy",
  datetime_format_full => "{1}, {0}",
  datetime_format_long => "{1}, {0}",
  datetime_format_medium => "{1}, {0}",
  datetime_format_short => "{1}, {0}",
  day_format_abbreviated => [
    "\N{U+091a}\N{U+0902}\N{U+0926}\N{U+093f}\N{U+0930}\N{U+0935}\N{U+093e}\N{U+0930}",
    "\N{U+092c}\N{U+0941}\N{U+0935}\N{U+093e}\N{U+0930}",
    "\N{U+092c}\N{U+094b}\N{U+0926}\N{U+0935}\N{U+093e}\N{U+0930}",
    "\N{U+092c}\N{U+094d}\N{U+0930}\N{U+0947}\N{U+0938}\N{U+0935}\N{U+093e}\N{U+0930}",
    "\N{U+091c}\N{U+0941}\N{U+092e}\N{U+093e}",
    "\N{U+092c}\N{U+091f}\N{U+0935}\N{U+093e}\N{U+0930}",
    "\N{U+0906}\N{U+0925}\N{U+0935}\N{U+093e}\N{U+0930}",
  ],
  day_format_narrow => [
    "\N{U+091a}",
    "\N{U+092c}",
    "\N{U+092c}",
    "\N{U+092c}",
    "\N{U+091c}",
    "\N{U+092c}",
    "\N{U+0905}",
  ],
  day_format_wide => [
    "\N{U+091a}\N{U+093c}\N{U+0902}\N{U+0926}\N{U+093f}\N{U+0930}\N{U+0935}\N{U+093e}\N{U+0930}",
    "\N{U+092c}\N{U+094b}\N{U+092e}\N{U+0935}\N{U+093e}\N{U+0930}",
    "\N{U+092c}\N{U+094b}\N{U+0926}\N{U+0935}\N{U+093e}\N{U+0930}",
    "\N{U+092c}\N{U+094d}\N{U+0930}\N{U+0947}\N{U+0938}\N{U+0935}\N{U+093e}\N{U+0930}",
    "\N{U+091c}\N{U+0941}\N{U+092e}\N{U+093e}",
    "\N{U+092c}\N{U+091f}\N{U+0935}\N{U+093e}\N{U+0930}",
    "\N{U+0906}\N{U+0925}\N{U+0935}\N{U+093e}\N{U+0930}",
  ],
  day_stand_alone_abbreviated => [
    "\N{U+091a}\N{U+0902}\N{U+0926}\N{U+093f}\N{U+0930}\N{U+0935}\N{U+093e}\N{U+0930}",
    "\N{U+092c}\N{U+0941}\N{U+0935}\N{U+093e}\N{U+0930}",
    "\N{U+092c}\N{U+094b}\N{U+0926}\N{U+0935}\N{U+093e}\N{U+0930}",
    "\N{U+092c}\N{U+094d}\N{U+0930}\N{U+0947}\N{U+0938}\N{U+0935}\N{U+093e}\N{U+0930}",
    "\N{U+091c}\N{U+0941}\N{U+092e}\N{U+094d}\N{U+092e}\N{U+093e}",
    "\N{U+092c}\N{U+091f}\N{U+0935}\N{U+093e}\N{U+0930}",
    "\N{U+0906}\N{U+0925}\N{U+0935}\N{U+093e}\N{U+0930}",
  ],
  day_stand_alone_narrow => [
    "\N{U+091a}",
    "\N{U+092c}",
    "\N{U+092c}",
    "\N{U+092c}",
    "\N{U+091c}",
    "\N{U+092c}",
    "\N{U+0905}",
  ],
  day_stand_alone_wide => [
    "\N{U+091a}\N{U+0902}\N{U+0926}\N{U+093f}\N{U+0930}\N{U+0935}\N{U+093e}\N{U+0930}",
    "\N{U+092c}\N{U+0941}\N{U+0935}\N{U+093e}\N{U+0930}",
    "\N{U+092c}\N{U+094b}\N{U+0926}\N{U+0935}\N{U+093e}\N{U+0930}",
    "\N{U+092c}\N{U+094d}\N{U+0930}\N{U+0947}\N{U+0938}\N{U+0935}\N{U+093e}\N{U+0930}",
    "\N{U+091c}\N{U+0941}\N{U+092e}\N{U+094d}\N{U+092e}\N{U+093e}",
    "\N{U+092c}\N{U+091f}\N{U+0935}\N{U+093e}\N{U+0930}",
    "\N{U+0906}\N{U+0925}\N{U+0935}\N{U+093e}\N{U+0930}",
  ],
  era_abbreviated => [
    "BC",
    "AD",
  ],
  era_narrow => [
    "BC",
    "AD",
  ],
  era_wide => [
    "\N{U+0908}\N{U+0938}\N{U+093e} \N{U+092c}\N{U+094d}\N{U+0930}\N{U+094b}\N{U+0902}\N{U+0920}",
    "\N{U+0908}\N{U+0938}\N{U+094d}\N{U+0935}\N{U+0940}",
  ],
  first_day_of_week => 7,
  glibc_date_1_format => "%A %d %b %Y %I:%M:%S %p %Z",
  glibc_date_format => "%-m/%-d/%y",
  glibc_datetime_format => "%A %d %b %Y %I:%M:%S %p",
  glibc_time_12_format => "%I:%M:%S %p %Z",
  glibc_time_format => "%I:%M:%S %p %Z",
  language => "Kashmiri",
  month_format_abbreviated => [
    "\N{U+091c}\N{U+0928}\N{U+0935}\N{U+0930}\N{U+0940}",
    "\N{U+092b}\N{U+093c}\N{U+0930}\N{U+0935}\N{U+0930}\N{U+0940}",
    "\N{U+092e}\N{U+093e}\N{U+0930}\N{U+094d}\N{U+091a}",
    "\N{U+0905}\N{U+092a}\N{U+094d}\N{U+0930}\N{U+0948}\N{U+0932}",
    "\N{U+092e}\N{U+0947}",
    "\N{U+091c}\N{U+0942}\N{U+0928}",
    "\N{U+091c}\N{U+0941}\N{U+0932}\N{U+093e}\N{U+0908}",
    "\N{U+0905}\N{U+0917}\N{U+0938}\N{U+094d}\N{U+0924}",
    "\N{U+0938}\N{U+0924}\N{U+0941}\N{U+0902}\N{U+092c}\N{U+0930}",
    "\N{U+0905}\N{U+0915}\N{U+094d}\N{U+0924}\N{U+0942}\N{U+092c}\N{U+0930}",
    "\N{U+0928}\N{U+0935}\N{U+0942}\N{U+092e}\N{U+092c}\N{U+0930}",
    "\N{U+0926}\N{U+0938}\N{U+0942}\N{U+092e}\N{U+092c}\N{U+0930}",
  ],
  month_format_narrow => [
    "\N{U+091c}",
    "\N{U+092b}\N{U+093c}",
    "\N{U+092e}",
    "\N{U+0905}",
    "\N{U+092e}",
    "\N{U+091c}",
    "\N{U+091c}",
    "\N{U+0905}",
    "\N{U+0938}",
    "\N{U+0913}",
    "\N{U+0928}",
    "\N{U+0926}",
  ],
  month_format_wide => [
    "\N{U+091c}\N{U+0928}\N{U+0935}\N{U+0930}\N{U+0940}",
    "\N{U+092b}\N{U+093c}\N{U+0930}\N{U+0935}\N{U+0930}\N{U+0940}",
    "\N{U+092e}\N{U+093e}\N{U+0930}\N{U+094d}\N{U+091a}",
    "\N{U+0905}\N{U+092a}\N{U+094d}\N{U+0930}\N{U+0948}\N{U+0932}",
    "\N{U+092e}\N{U+0947}",
    "\N{U+091c}\N{U+0942}\N{U+0928}",
    "\N{U+091c}\N{U+0941}\N{U+0932}\N{U+093e}\N{U+0908}",
    "\N{U+0905}\N{U+0917}\N{U+0938}\N{U+094d}\N{U+0924}",
    "\N{U+0938}\N{U+0924}\N{U+092e}\N{U+092c}\N{U+0930}",
    "\N{U+0905}\N{U+0915}\N{U+094d}\N{U+0924}\N{U+0942}\N{U+092c}\N{U+0930}",
    "\N{U+0928}\N{U+0935}\N{U+092e}\N{U+092c}\N{U+0930}",
    "\N{U+0926}\N{U+0938}\N{U+092e}\N{U+092c}\N{U+0930}",
  ],
  month_stand_alone_abbreviated => [
    "\N{U+091c}\N{U+0928}\N{U+0935}\N{U+0930}\N{U+0940}",
    "\N{U+092b}\N{U+093c}\N{U+0930}\N{U+0935}\N{U+0930}\N{U+0940}",
    "\N{U+092e}\N{U+093e}\N{U+0930}\N{U+094d}\N{U+091a}",
    "\N{U+0905}\N{U+092a}\N{U+094d}\N{U+0930}\N{U+0948}\N{U+0932}",
    "\N{U+092e}\N{U+0947}",
    "\N{U+091c}\N{U+0942}\N{U+0928}",
    "\N{U+091c}\N{U+0941}\N{U+0932}\N{U+093e}\N{U+0908}",
    "\N{U+0905}\N{U+0917}\N{U+0938}\N{U+094d}\N{U+0924}",
    "\N{U+0938}\N{U+0924}\N{U+0941}\N{U+0902}\N{U+092c}\N{U+0930}",
    "\N{U+0905}\N{U+0915}\N{U+0924}\N{U+0941}\N{U+092e}\N{U+094d}\N{U+092c}\N{U+0930}",
    "\N{U+0928}\N{U+0935}\N{U+0942}\N{U+092e}\N{U+092c}\N{U+0930}",
    "\N{U+0926}\N{U+0938}\N{U+0942}\N{U+092e}\N{U+092c}\N{U+0930}",
  ],
  month_stand_alone_narrow => [
    "\N{U+091c}",
    "\N{U+092b}\N{U+093c}",
    "\N{U+092e}",
    "\N{U+0905}",
    "\N{U+092e}",
    "\N{U+091c}",
    "\N{U+091c}",
    "\N{U+0905}",
    "\N{U+0938}",
    "\N{U+0913}",
    "\N{U+0928}",
    "\N{U+0926}",
  ],
  month_stand_alone_wide => [
    "\N{U+091c}\N{U+0928}\N{U+0935}\N{U+0930}\N{U+0940}",
    "\N{U+092b}\N{U+093c}\N{U+0930}\N{U+0935}\N{U+0930}\N{U+0940}",
    "\N{U+092e}\N{U+093e}\N{U+0930}\N{U+094d}\N{U+091a}",
    "\N{U+0905}\N{U+092a}\N{U+094d}\N{U+0930}\N{U+0948}\N{U+0932}",
    "\N{U+092e}\N{U+0947}",
    "\N{U+091c}\N{U+0942}\N{U+0928}",
    "\N{U+091c}\N{U+0941}\N{U+0932}\N{U+093e}\N{U+0908}",
    "\N{U+0905}\N{U+0917}\N{U+0938}\N{U+094d}\N{U+0924}",
    "\N{U+0938}\N{U+0924}\N{U+0941}\N{U+0902}\N{U+092c}\N{U+0930}",
    "\N{U+0905}\N{U+0915}\N{U+0924}\N{U+0941}\N{U+092e}\N{U+094d}\N{U+092c}\N{U+0930}",
    "\N{U+0928}\N{U+0935}\N{U+0942}\N{U+092e}\N{U+092c}\N{U+0930}",
    "\N{U+0926}\N{U+0938}\N{U+0942}\N{U+092e}\N{U+092c}\N{U+0930}",
  ],
  name => "Kashmiri India Devanagari",
  native_language => "\N{U+0915}\N{U+0949}\N{U+0936}\N{U+0941}\N{U+0930}",
  native_name => "\N{U+0915}\N{U+0949}\N{U+0936}\N{U+0941}\N{U+0930} \N{U+0939}\N{U+093f}\N{U+0902}\N{U+0926}\N{U+094b}\N{U+0938}\N{U+094d}\N{U+0924}\N{U+093e}\N{U+0928} \N{U+0926}\N{U+0947}\N{U+0935}\N{U+0928}\N{U+093e}\N{U+0917}\N{U+0930}\N{U+0940}",
  native_script => "\N{U+0926}\N{U+0947}\N{U+0935}\N{U+0928}\N{U+093e}\N{U+0917}\N{U+0930}\N{U+0940}",
  native_territory => "\N{U+0939}\N{U+093f}\N{U+0902}\N{U+0926}\N{U+094b}\N{U+0938}\N{U+094d}\N{U+0924}\N{U+093e}\N{U+0928}",
  native_variant => undef,
  quarter_format_abbreviated => [
    "Q1",
    "Q2",
    "Q3",
    "Q4",
  ],
  quarter_format_narrow => [
    1,
    2,
    3,
    4,
  ],
  quarter_format_wide => [
    "1st \N{U+0938}\N{U+0939} \N{U+092e}\N{U+093e}\N{U+0939}",
    "2nd \N{U+0938}\N{U+0939} \N{U+092e}\N{U+093e}\N{U+0939}",
    "3rd \N{U+0938}\N{U+0939} \N{U+092e}\N{U+093e}\N{U+0939}",
    "4th \N{U+0938}\N{U+0939} \N{U+092e}\N{U+093e}\N{U+0939}",
  ],
  quarter_stand_alone_abbreviated => [
    "Q1",
    "Q2",
    "Q3",
    "Q4",
  ],
  quarter_stand_alone_narrow => [
    1,
    2,
    3,
    4,
  ],
  quarter_stand_alone_wide => [
    "1st \N{U+0938}\N{U+0939} \N{U+092e}\N{U+093e}\N{U+0939}",
    "2nd \N{U+0938}\N{U+0939} \N{U+092e}\N{U+093e}\N{U+0939}",
    "3rd \N{U+0938}\N{U+0939} \N{U+092e}\N{U+093e}\N{U+0939}",
    "4th \N{U+0938}\N{U+0939} \N{U+092e}\N{U+093e}\N{U+0939}",
  ],
  script => "Devanagari",
  territory => "India",
  time_format_full => "a h:mm:ss zzzz",
  time_format_long => "a h:mm:ss z",
  time_format_medium => "a h:mm:ss",
  time_format_short => "a h:mm",
  variant => undef,
  version => "44.1",
}
